# llm-dspy

[![Release](https://img.shields.io/github/v/release/imaurer/llm-dspy)](https://img.shields.io/github/v/release/imaurer/llm-dspy)
[![Build status](https://img.shields.io/github/actions/workflow/status/imaurer/llm-dspy/main.yml?branch=main)](https://github.com/imaurer/llm-dspy/actions/workflows/main.yml?query=branch%3Amain)
[![Commit activity](https://img.shields.io/github/commit-activity/m/imaurer/llm-dspy)](https://img.shields.io/github/commit-activity/m/imaurer/llm-dspy)
[![License](https://img.shields.io/github/license/imaurer/llm-dspy)](https://img.shields.io/github/license/imaurer/llm-dspy)

llm plugin for dspy
